@@ -1,6 +1,7 @@
 from datetime import datetime
-from typing import Callable, Dict, Any, Tuple
+from typing import Callable, Dict, Any, Tuple, List, Mapping, Union
 
+from pymongo.cursor import Cursor
 from typeguard import typechecked
 
 from openai_wrapper.config import Config
@@ -139,3 +140,52 @@ class Completion:
         mongo_collection.insert_one(document)
 
         return document
+
+    def get_completions_for_prompt(self, prompt: str, prompt_version: str = None) -> List[Dict[Any, Any]]:
+        """
+        Get all completions for a given prompt
+
+        Args:
+            prompt: The prompt to get completions for
+            prompt_version: The version of the prompt (e.g. "1.0")
+
+        Returns:
+            A list of completions
+        """
+
+        mongo_db = self.mongo_client[self.config.mongo_db_name]
+        mongo_collection = mongo_db[self.collection_name]
+        if prompt_version:
+            return list(mongo_collection.find({"prompt": prompt, "prompt_version": prompt_version}))
+        else:
+            return list(mongo_collection.find({"prompt": prompt}))
+
+    def get_completion_by_id(self, completion_id: str) -> Dict[Any, Any]:
+        """
+        Get a completion by its id
+
+        Args:
+            completion_id: The id of the completion to get
+
+        Returns:
+            A dictionary containing the completion
+        """
+        from bson import ObjectId
+
+        mongo_db = self.mongo_client[self.config.mongo_db_name]
+        mongo_collection = mongo_db[self.collection_name]
+        return mongo_collection.find_one({"_id": ObjectId(completion_id)})
+
+    def get_completions_using_mongodb_filter(self, filters: Dict[Any, Any]) -> List[Dict[Any, Any]]:
+        """
+        Get completions by a MongoDB filter
+
+        Args:
+            filters: The filter to use to find the completion (e.g. {"prompt": "Hello", "prompt_version": "1.0"}
+
+        Returns:
+            A dictionary containing the completion
+        """
+        mongo_db = self.mongo_client[self.config.mongo_db_name]
+        mongo_collection = mongo_db[self.collection_name]
+        return list(mongo_collection.find(filters))
